banzhaf_appro: Banzhaf Index (approximated)

View source: R/banzhaf_appro.R

banzhaf_approR Documentation

Banzhaf Index (approximated)

Description

Calculate the approximated Banzhaf Index based on sampling

Usage

banzhaf_appro(characteristic_func, n_players, n_rep, replace = TRUE)

Arguments

characteristic_func

The valued function defined on the subsets of the number of players

n_players

The number of players

n_rep

The number of iterations to perform in the approximated calculation

replace

should sampling be with replacement?

Value

The Shapley value for each player


TUvalues documentation built on June 8, 2025, 10:50 a.m.