Learn R Programming

TUvalues (version 1.1.0)

banzhaf_owen_appro: Banzhaf-Owen Value

Description

Calculate the approximated Banzhaf-Owen value using the algorithm proposed by Saavedra-Nieves & Fiestras-Janeiro (2021).

Usage

banzhaf_owen_appro(characteristic_func, union, n_players, n_rep, replace, echo)

Value

The Banzhaf-Owen Index for each player

Arguments

characteristic_func

The valued function defined on the subsets of the number of players

union

List of vectors indicating the a priori unions between the players

n_players

The number of players

n_rep

Only used if method is appro. The number of iterations to perform in the approximated calculation.

replace

Should sampling be with replacement?

echo

Show progress of the calculation.

References

Saavedra-Nieves, A., & Fiestras-Janeiro, M. G. (2021). Sampling methods to estimate the Banzhaf–Owen value. Annals of Operations Research, 301(1), 199-223.