Learn R Programming

TUvalues (version 1.1.1)

owen_appro: Owen value (approximation)

Description

Calculate the approximated Owen value based on sampling using the algorithm proposed by Saavedra-Nieves et al. (2018).

Usage

owen_appro(characteristic_func, union, n_players, n_rep, echo)

Value

The Owen value for each player

Arguments

characteristic_func

The valued function defined on the subsets of the number of players

union

List of vectors indicating the a priori unions between the players

n_players

The number of players

n_rep

The number of iterations to perform in the approximated calculation

echo

Show progress of the calculation.

References

Saavedra-Nieves, A., García-Jurado, I., & Fiestras-Janeiro, M. G. (2018). Estimation of the Owen value based on sampling. In The mathematics of the uncertain: A tribute to Pedro Gil (pp. 347-356). Cham: Springer International Publishing.