Learn R Programming

TUvalues (version 1.1.1)

shapley_appro: Shapley value (approximation)

Description

Calculate the approximated Shapley value based on sampling using the algorithm proposed by Castro et al. (2009).

Usage

shapley_appro(characteristic_func, n_players, n_rep, echo)

Value

The Shapley value for each player

Arguments

characteristic_func

The valued function defined on the subsets of the number of players

n_players

The number of players

n_rep

The number of iterations to perform in the approximated calculation

echo

Show progress of the calculation.

References

Castro, J., Gómez, D., & Tejada, J. (2009). Polynomial calculation of the Shapley value based on sampling. Computers & operations research, 36(5), 1726-1730.