Calculate the approximated Banzhaf Index based on sampling
banzhaf_appro(characteristic_func, n_players, n_rep, replace = TRUE)The Banzhaf Index for each player
The valued function defined on the subsets of the number of players
Only used if value_func is a function.
The number of players in the game
The number of iterations to perform in the approximated calculation
should sampling be with replacement?