Calculate the approximated Banzhaf-Owen value using the algorithm proposed by Saavedra-Nieves & Fiestras-Janeiro (2021).
banzhaf_owen_appro(characteristic_func, union, n_players, n_rep, replace, echo)The Banzhaf-Owen Index for each player
The valued function defined on the subsets of the number of players
List of vectors indicating the a priori unions between the players
The number of players
Only used if method is appro. The number of
iterations to perform in the approximated calculation.
Should sampling be with replacement?
Show progress of the calculation.
Saavedra-Nieves, A., & Fiestras-Janeiro, M. G. (2021). Sampling methods to estimate the Banzhaf–Owen value. Annals of Operations Research, 301(1), 199-223.