Calculate the approximated Owen value based on sampling using the algorithm proposed by Saavedra-Nieves et al. (2018).
owen_appro(characteristic_func, union, n_players, n_rep, echo)The Owen value for each player
The valued function defined on the subsets of the number of players
List of vectors indicating the a priori unions between the players
The number of players
The number of iterations to perform in the approximated calculation
Show progress of the calculation.
Saavedra-Nieves, A., García-Jurado, I., & Fiestras-Janeiro, M. G. (2018). Estimation of the Owen value based on sampling. In The mathematics of the uncertain: A tribute to Pedro Gil (pp. 347-356). Cham: Springer International Publishing.