Calculate the approximated Shapley value based on sampling using the algorithm proposed by Castro et al. (2009).
shapley_appro(characteristic_func, n_players, n_rep, echo)The Shapley value for each player
The valued function defined on the subsets of the number of players
The number of players
The number of iterations to perform in the approximated calculation
Show progress of the calculation.
Castro, J., Gómez, D., & Tejada, J. (2009). Polynomial calculation of the Shapley value based on sampling. Computers & operations research, 36(5), 1726-1730.